@@ -1,5 +1,5 @@
-{% set template_domain_import = "shared.domain"|compute_base_path(template) %}
-from {{ source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
+{% set template_domain_import = "shared.domain"|compute_base_path(template.name) %}
+from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
 
 
 class AggregateRoot:
